.. _theory:

===========================
Methods and Theory
===========================

.. toctree::
   :maxdepth: 3

   lattice_calcs.rst
   self_shielding.rst
   pin_cell_calc.rst
   assembly_calc.rst
   nodal_diffusion.rst
